<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Help</name>
    <message>
        <location filename="../Help.js" line="+60"/>
        <source>&amp;Help</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Pomoc
Pomo&amp;c Qt Designer</translatorcomment>
        <translation>Pomo&amp;c</translation>
    </message>
</context>
</TS>
